==> endeavour_2.8.2.orig.tar.gz: endeavour-2.8.2/endeavour2/customize_win.h <==
/*
                      Endeavour Customize Window
 */

#ifndef CUSTOMIZE_WIN_H
#define CUSTOMIZE_WIN_H

#include <gtk/gtk.h>
#include "edv_types.h"
#include "edv_generic_options_win.h"


/* File Browser */
extern void EDVCustomizeBrowserCreateKeymapsPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeBrowserCreateContentsListPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeBrowserCreateToolBarPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeBrowserCreateAppearancePage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Image Browser */
extern void EDVCustomizeImbrCreatePresentationPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent                                
);
extern void EDVCustomizeImbrCreateKeymapsPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeImbrCreateThumbsListPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeImbrCreateToolBarPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeImbrCreateAppearancePage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Archiver */
extern void EDVCustomizeArchiverCreateKeymapsPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent                                
);
extern void EDVCustomizeArchiverCreateContentsListPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeArchiverCreateToolBarPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeArchiverCreateAppearancePage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Recycle Bin */
extern void EDVCustomizeRecBinCreateKeymapsPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeRecBinCreateContentsListPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeRecBinCreateToolBarPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeRecBinCreateAppearancePage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);


/* Utilities */
extern gchar *EDVCustomizeSimplifyOPIDName(const gchar *name);


/* General */
extern void EDVCustomizeGeneralCreateNewObjectsMenuPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeGeneralCreateStylesPage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeGeneralCreateAppearancePage(
	edv_core_struct *core, edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Customize Window */
extern gboolean EDVCustomizeWindowSelectTab(
	edv_gen_opt_win_struct *optwin, const gchar *tab_name
);
extern edv_gen_opt_win_struct *EDVCustomizeWindowNew(edv_core_struct *core);


#endif	/* CUSTOMIZE_WIN_H */

==> endeavour_2.8.4.orig.tar.gz: endeavour-2.8.4/endeavour2/customize_win.h <==
/*
                      Endeavour Customize Window
 */

#ifndef CUSTOMIZE_WIN_H
#define CUSTOMIZE_WIN_H

#include <gtk/gtk.h>
#include "edv_types.h"
#include "edv_generic_options_win.h"


/* File Browser */
extern void EDVCustomizeBrowserCreateKeymapsPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeBrowserCreateContentsListPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeBrowserCreateToolBarPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeBrowserCreateAppearancePage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Image Browser */
extern void EDVCustomizeImbrCreatePresentationPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent                                
);
extern void EDVCustomizeImbrCreateKeymapsPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeImbrCreateThumbsListPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeImbrCreateToolBarPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeImbrCreateAppearancePage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Archiver */
extern void EDVCustomizeArchiverCreateKeymapsPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent                                
);
extern void EDVCustomizeArchiverCreateContentsListPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeArchiverCreateToolBarPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeArchiverCreateAppearancePage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Recycle Bin */
extern void EDVCustomizeRecBinCreateKeymapsPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeRecBinCreateContentsListPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeRecBinCreateToolBarPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeRecBinCreateAppearancePage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);


/* Utilities */
extern gchar *EDVCustomizeSimplifyOPIDName(const gchar *name);


/* General */
extern void EDVCustomizeGeneralCreateNewObjectsMenuPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeGeneralCreateStylesPage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);
extern void EDVCustomizeGeneralCreateAppearancePage(
	edv_core_struct *core,
	edv_gen_opt_win_struct *optwin,
	GtkWidget *parent
);

/* Customize Window */
extern gboolean EDVCustomizeWindowSelectTab(
	edv_gen_opt_win_struct *optwin,
	const gchar *tab_name
);
extern edv_gen_opt_win_struct *EDVCustomizeWindowNew(edv_core_struct *core);


#endif	/* CUSTOMIZE_WIN_H */
